==> ocp-common-3.0.0-20190814.041451-53-sources.jar: com/efuture/ocp/common/billservice/AsyncauditlistBean.java <==
package com.efuture.ocp.common.billservice;

import java.util.Date;

import org.springframework.data.mongodb.core.mapping.Document;
@Document(collection="asyncauditlist")
public class AsyncauditlistBean extends BillAbstractBean {
	/**
	 * 
	 */
	private static final long serialVersionUID = -238910151366045504L;
	long 	ph_key;//
	String billno;//单号
	String billmoduleid;//模块号
	String execstatus;//执行状态
	String auditor;//审核人
	String auditor_name;//审核人名称
	String billobjectname;//执行对象名称
	String billobjectclass;//执行对象类型
	int execcount;//要执行数据行数
	int execed;//已执行数据行数
	Date execsdate;//执行开始时间
	Date execedate;//执行结束时间
	long execelapsed;//耗时
	String execerrmsg;//错误信息
	public long getPh_key() {
		return ph_key;
	}

	public void setPh_key(long ph_key) {
		this.ph_key = ph_key;
	}

	public String getBillno() {
		return billno;
	}

	public void setBillno(String billno) {
		this.billno = billno;
	}

	public String getBillmoduleid() {
		return billmoduleid;
	}

	public void setBillmoduleid(String billmoduleid) {
		this.billmoduleid = billmoduleid;
	}

	public String getBillobjectname() {
		return billobjectname;
	}

	public void setBillobjectname(String billobjectname) {
		this.billobjectname = billobjectname;
	}

	public String getBillobjectclass() {
		return billobjectclass;
	}

	public void setBillobjectclass(String billobjectclass) {
		this.billobjectclass = billobjectclass;
	}

	public String getExecstatus() {
		return execstatus;
	}

	public void setExecstatus(String execstatus) {
		this.execstatus = execstatus;
	}

	

	public String getAuditor() {
		return auditor;
	}

	public void setAuditor(String auditor) {
		this.auditor = auditor;
	}

	public String getAuditor_name() {
		return auditor_name;
	}

	public void setAuditor_name(String auditor_name) {
		this.auditor_name = auditor_name;
	}

	public int getExeccount() {
		return execcount;
	}

	public void setExeccount(int execcount) {
		this.execcount = execcount;
	}

	public int getExeced() {
		return execed;
	}

	public void setExeced(int execed) {
		this.execed = execed;
	}

	public Date getExecsdate() {
		return execsdate;
	}

	public void setExecsdate(Date execsdate) {
		this.execsdate = execsdate;
	}

	public Date getExecedate() {
		return execedate;
	}

	public void setExecedate(Date execedate) {
		this.execedate = execedate;
	}

	public long getExecelapsed() {
		return execelapsed;
	}

	public void setExecelapsed(long execelapsed) {
		this.execelapsed = execelapsed;
	}

	public String getExecerrmsg() {
		return execerrmsg;
	}

	public void setExecerrmsg(String execerrmsg) {
		this.execerrmsg = execerrmsg;
	}

}

==> ocp-common-5.0.0-20231208.095419-102-sources.jar: com/efuture/ocp/common/billservice/AsyncauditlistBean.java <==
package com.efuture.ocp.common.billservice;

import java.util.Date;

import org.springframework.data.mongodb.core.mapping.Document;
@Document(collection="asyncauditlist")
public class AsyncauditlistBean extends BillAbstractBean {
	/**
	 * 
	 */
	private static final long serialVersionUID = -238910151366045504L;
//	long 	ph_key;//
	String billno;//单号
	String billmoduleid;//模块号
	String execstatus;//执行状态
	String auditor;//审核人
	String auditor_name;//审核人名称
	String billobjectname;//执行对象名称
	String billobjectclass;//执行对象类型
	int execcount;//要执行数据行数
	int execed;//已执行数据行数
	Date execsdate;//执行开始时间
	Date execedate;//执行结束时间
	long execelapsed;//耗时
	String execerrmsg;//错误信息
//	public long getPh_key() {
//		return ph_key;
//	}

//	public void setPh_key(long ph_key) {
//		this.ph_key = ph_key;
//	}

	public String getBillno() {
		return billno;
	}

	public void setBillno(String billno) {
		this.billno = billno;
	}

	public String getBillmoduleid() {
		return billmoduleid;
	}

	public void setBillmoduleid(String billmoduleid) {
		this.billmoduleid = billmoduleid;
	}

	public String getBillobjectname() {
		return billobjectname;
	}

	public void setBillobjectname(String billobjectname) {
		this.billobjectname = billobjectname;
	}

	public String getBillobjectclass() {
		return billobjectclass;
	}

	public void setBillobjectclass(String billobjectclass) {
		this.billobjectclass = billobjectclass;
	}

	public String getExecstatus() {
		return execstatus;
	}

	public void setExecstatus(String execstatus) {
		this.execstatus = execstatus;
	}

	

	public String getAuditor() {
		return auditor;
	}

	public void setAuditor(String auditor) {
		this.auditor = auditor;
	}

	public String getAuditor_name() {
		return auditor_name;
	}

	public void setAuditor_name(String auditor_name) {
		this.auditor_name = auditor_name;
	}

	public int getExeccount() {
		return execcount;
	}

	public void setExeccount(int execcount) {
		this.execcount = execcount;
	}

	public int getExeced() {
		return execed;
	}

	public void setExeced(int execed) {
		this.execed = execed;
	}

	public Date getExecsdate() {
		return execsdate;
	}

	public void setExecsdate(Date execsdate) {
		this.execsdate = execsdate;
	}

	public Date getExecedate() {
		return execedate;
	}

	public void setExecedate(Date execedate) {
		this.execedate = execedate;
	}

	public long getExecelapsed() {
		return execelapsed;
	}

	public void setExecelapsed(long execelapsed) {
		this.execelapsed = execelapsed;
	}

	public String getExecerrmsg() {
		return execerrmsg;
	}

	public void setExecerrmsg(String execerrmsg) {
		this.execerrmsg = execerrmsg;
	}

}
